@@ -2,12 +2,12 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.000000';
+$MetaCPAN::Client::Request::VERSION = '1.000001';
 use Moo;
 use Carp;
 use JSON;
-use Elasticsearch;
-use Elasticsearch::Scroll;
+use Search::Elasticsearch;
+use Search::Elasticsearch::Scroll;
 use Try::Tiny;
 use HTTP::Tiny;
 
@@ -68,13 +68,13 @@ sub ssearch {
     my $args   = shift;
     my $params = shift;
 
-    my $es = Elasticsearch->new(
+    my $es = Search::Elasticsearch->new(
         nodes            => $self->domain,
         cxn_pool         => 'Static::NoPing',
         send_get_body_as => 'POST',
     );
 
-    my $scroller = Elasticsearch::Scroll->new(
+    my $scroller = Search::Elasticsearch::Scroll->new(
         es          => $es,
         search_type => 'scan',
         scroll      => '5m',
@@ -182,7 +182,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.000000
+version 1.000001
 
 =head1 ATTRIBUTES
 
@@ -266,8 +266,8 @@ Fetches a path from MetaCPAN (post or get), and returns the decoded result.
 
 =head2 ssearch
 
-Calls an Elastic Search query (using L<Elasticsearch> and returns an
-L<Elasticsearch::Scroll> scroller object.
+Calls an Elastic Search query (using L<Search::Elasticsearch> and returns an
+L<Search::Elasticsearch::Scroll> scroller object.
 
 =head1 AUTHORS
 
